# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qm/pb/inc_qua_config.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'qm/pb/inc_qua_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aqm/pb/inc_qua_config.proto\x12\x12qm.grpc.qua_config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xbd\xa1\x01\n\tQuaConfig\x12;\n\x06v1beta\x18\x01 \x01(\x0b\x32).qm.grpc.qua_config.QuaConfig.QuaConfigV1H\x00\x12\x37\n\x02v2\x18\x02 \x01(\x0b\x32).qm.grpc.qua_config.QuaConfig.QuaConfigV2H\x00\x12\x10\n\x08revision\x18\x0b \x01(\x05\x1a\xef\r\n\x0bQuaConfigV1\x12S\n\x0b\x63ontrollers\x18\x02 \x03(\x0b\x32:.qm.grpc.qua_config.QuaConfig.QuaConfigV1.ControllersEntryB\x02\x18\x01\x12U\n\x0e\x63ontrolDevices\x18\x14 \x03(\x0b\x32=.qm.grpc.qua_config.QuaConfig.QuaConfigV1.ControlDevicesEntry\x12O\n\x0boscillators\x18\t \x03(\x0b\x32:.qm.grpc.qua_config.QuaConfig.QuaConfigV1.OscillatorsEntry\x12I\n\x08\x65lements\x18\x03 \x03(\x0b\x32\x37.qm.grpc.qua_config.QuaConfig.QuaConfigV1.ElementsEntry\x12\x45\n\x06pulses\x18\x04 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.QuaConfigV1.PulsesEntry\x12\x45\n\x06mixers\x18\x05 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.QuaConfigV1.MixersEntry\x12K\n\twaveforms\x18\x06 \x03(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.QuaConfigV1.WaveformsEntry\x12Y\n\x10\x64igitalWaveforms\x18\x07 \x03(\x0b\x32?.qm.grpc.qua_config.QuaConfig.QuaConfigV1.DigitalWaveformsEntry\x12]\n\x12integrationWeights\x18\x08 \x03(\x0b\x32\x41.qm.grpc.qua_config.QuaConfig.QuaConfigV1.IntegrationWeightsEntry\x12G\n\x07octaves\x18\x0b \x03(\x0b\x32\x36.qm.grpc.qua_config.QuaConfig.QuaConfigV1.OctavesEntry\x1a_\n\x10\x43ontrollersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.ControllerDec:\x02\x38\x01\x1a^\n\x13\x43ontrolDevicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.qm.grpc.qua_config.QuaConfig.DeviceDec:\x02\x38\x01\x1a\\\n\x10OscillatorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qm.grpc.qua_config.QuaConfig.Oscillator:\x02\x38\x01\x1aY\n\rElementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qm.grpc.qua_config.QuaConfig.ElementDec:\x02\x38\x01\x1aU\n\x0bPulsesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.PulseDec:\x02\x38\x01\x1aU\n\x0bMixersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.MixerDec:\x02\x38\x01\x1a[\n\x0eWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qm.grpc.qua_config.QuaConfig.WaveformDec:\x02\x38\x01\x1ai\n\x15\x44igitalWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.qm.grpc.qua_config.QuaConfig.DigitalWaveformDec:\x02\x38\x01\x1am\n\x17IntegrationWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.IntegrationWeightDec:\x02\x38\x01\x1a[\n\x0cOctavesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.Octave.Config:\x02\x38\x01\x1a\x9d\x01\n\x0bQuaConfigV2\x12I\n\x11\x63ontroller_config\x18\x01 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.ControllerConfig\x12\x43\n\x0elogical_config\x18\x02 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.LogicalConfig\x1a\x9c\x04\n\x10\x43ontrollerConfig\x12Z\n\x0e\x63ontrolDevices\x18\x01 \x03(\x0b\x32\x42.qm.grpc.qua_config.QuaConfig.ControllerConfig.ControlDevicesEntry\x12J\n\x06mixers\x18\x02 \x03(\x0b\x32:.qm.grpc.qua_config.QuaConfig.ControllerConfig.MixersEntry\x12L\n\x07octaves\x18\x03 \x03(\x0b\x32;.qm.grpc.qua_config.QuaConfig.ControllerConfig.OctavesEntry\x1a^\n\x13\x43ontrolDevicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.qm.grpc.qua_config.QuaConfig.DeviceDec:\x02\x38\x01\x1aU\n\x0bMixersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.MixerDec:\x02\x38\x01\x1a[\n\x0cOctavesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.Octave.Config:\x02\x38\x01\x1a\xcc\x08\n\rLogicalConfig\x12K\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x39.qm.grpc.qua_config.QuaConfig.LogicalConfig.ElementsEntry\x12Q\n\x0boscillators\x18\x02 \x03(\x0b\x32<.qm.grpc.qua_config.QuaConfig.LogicalConfig.OscillatorsEntry\x12G\n\x06pulses\x18\x03 \x03(\x0b\x32\x37.qm.grpc.qua_config.QuaConfig.LogicalConfig.PulsesEntry\x12M\n\twaveforms\x18\x04 \x03(\x0b\x32:.qm.grpc.qua_config.QuaConfig.LogicalConfig.WaveformsEntry\x12[\n\x10\x64igitalWaveforms\x18\x05 \x03(\x0b\x32\x41.qm.grpc.qua_config.QuaConfig.LogicalConfig.DigitalWaveformsEntry\x12_\n\x12integrationWeights\x18\x06 \x03(\x0b\x32\x43.qm.grpc.qua_config.QuaConfig.LogicalConfig.IntegrationWeightsEntry\x1aY\n\rElementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qm.grpc.qua_config.QuaConfig.ElementDec:\x02\x38\x01\x1a\\\n\x10OscillatorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qm.grpc.qua_config.QuaConfig.Oscillator:\x02\x38\x01\x1aU\n\x0bPulsesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.PulseDec:\x02\x38\x01\x1a[\n\x0eWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qm.grpc.qua_config.QuaConfig.WaveformDec:\x02\x38\x01\x1ai\n\x15\x44igitalWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.qm.grpc.qua_config.QuaConfig.DigitalWaveformDec:\x02\x38\x01\x1am\n\x17IntegrationWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.IntegrationWeightDec:\x02\x38\x01\x1a\xa1\x01\n\tDeviceDec\x12?\n\x04\x66\x65ms\x18\x01 \x03(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.DeviceDec.FemsEntry\x1aS\n\tFemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.FEMTypes:\x02\x38\x01\x1a\xde\x01\n\x08\x46\x45MTypes\x12:\n\x03opx\x18\x01 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.ControllerDecH\x00\x12?\n\x08octo_dac\x18\x02 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.OctoDacFemDecH\x00\x12\x42\n\tmicrowave\x18\x03 \x01(\x0b\x32-.qm.grpc.qua_config.QuaConfig.MicrowaveFemDecH\x00\x42\x11\n\x0f\x66\x65m_type_one_of\x1a\x9d\x06\n\rControllerDec\x12\x0c\n\x04type\x18\x01 \x01(\t\x12U\n\ranalogOutputs\x18\x02 \x03(\x0b\x32>.qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogOutputsEntry\x12S\n\x0c\x61nalogInputs\x18\x03 \x03(\x0b\x32=.qm.grpc.qua_config.QuaConfig.ControllerDec.AnalogInputsEntry\x12W\n\x0e\x64igitalOutputs\x18\x04 \x03(\x0b\x32?.qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalOutputsEntry\x12U\n\rdigitalInputs\x18\x05 \x03(\x0b\x32>.qm.grpc.qua_config.QuaConfig.ControllerDec.DigitalInputsEntry\x1ag\n\x12\x41nalogOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec:\x02\x38\x01\x1a\x65\n\x11\x41nalogInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.qm.grpc.qua_config.QuaConfig.AnalogInputPortDec:\x02\x38\x01\x1ai\n\x13\x44igitalOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.DigitalOutputPortDec:\x02\x38\x01\x1ag\n\x12\x44igitalInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.DigitalInputPortDec:\x02\x38\x01\x1a\x96\x06\n\rOctoDacFemDec\x12U\n\ranalogOutputs\x18\x02 \x03(\x0b\x32>.qm.grpc.qua_config.QuaConfig.OctoDacFemDec.AnalogOutputsEntry\x12S\n\x0c\x61nalogInputs\x18\x03 \x03(\x0b\x32=.qm.grpc.qua_config.QuaConfig.OctoDacFemDec.AnalogInputsEntry\x12W\n\x0e\x64igitalOutputs\x18\x04 \x03(\x0b\x32?.qm.grpc.qua_config.QuaConfig.OctoDacFemDec.DigitalOutputsEntry\x12U\n\rdigitalInputs\x18\x05 \x03(\x0b\x32>.qm.grpc.qua_config.QuaConfig.OctoDacFemDec.DigitalInputsEntry\x1an\n\x12\x41nalogOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec:\x02\x38\x01\x1a\x65\n\x11\x41nalogInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.qm.grpc.qua_config.QuaConfig.AnalogInputPortDec:\x02\x38\x01\x1ai\n\x13\x44igitalOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.DigitalOutputPortDec:\x02\x38\x01\x1ag\n\x12\x44igitalInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.DigitalInputPortDec:\x02\x38\x01\x1a\xab\x06\n\x0fMicrowaveFemDec\x12W\n\ranalogOutputs\x18\x02 \x03(\x0b\x32@.qm.grpc.qua_config.QuaConfig.MicrowaveFemDec.AnalogOutputsEntry\x12U\n\x0c\x61nalogInputs\x18\x03 \x03(\x0b\x32?.qm.grpc.qua_config.QuaConfig.MicrowaveFemDec.AnalogInputsEntry\x12Y\n\x0e\x64igitalOutputs\x18\x04 \x03(\x0b\x32\x41.qm.grpc.qua_config.QuaConfig.MicrowaveFemDec.DigitalOutputsEntry\x12W\n\rdigitalInputs\x18\x05 \x03(\x0b\x32@.qm.grpc.qua_config.QuaConfig.MicrowaveFemDec.DigitalInputsEntry\x1ap\n\x12\x41nalogOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.qm.grpc.qua_config.QuaConfig.MicrowaveAnalogOutputPortDec:\x02\x38\x01\x1an\n\x11\x41nalogInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x39.qm.grpc.qua_config.QuaConfig.MicrowaveAnalogInputPortDec:\x02\x38\x01\x1ai\n\x13\x44igitalOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.DigitalOutputPortDec:\x02\x38\x01\x1ag\n\x12\x44igitalInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.DigitalInputPortDec:\x02\x38\x01\x1a\xcc\x04\n\x13\x41nalogOutputPortDec\x12\x13\n\x06offset\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x44\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x34.qm.grpc.qua_config.QuaConfig.AnalogOutputPortFilter\x12\x12\n\x05\x64\x65lay\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x61\n\x0e\x63hannelWeights\x18\x04 \x03(\x0b\x32\x45.qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.ChannelWeightsEntryB\x02\x18\x01\x12\x16\n\tshareable\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12S\n\tcrosstalk\x18\x06 \x03(\x0b\x32@.qm.grpc.qua_config.QuaConfig.AnalogOutputPortDec.CrosstalkEntry\x12\x1e\n\x11min_voltage_limit\x18\x07 \x01(\x01H\x03\x88\x01\x01\x12\x1e\n\x11max_voltage_limit\x18\x08 \x01(\x01H\x04\x88\x01\x01\x1a\x35\n\x13\x43hannelWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x30\n\x0e\x43rosstalkEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x42\t\n\x07_offsetB\x08\n\x06_delayB\x0c\n\n_shareableB\x14\n\x12_min_voltage_limitB\x14\n\x12_max_voltage_limit\x1a\x84\x06\n\x1cMicrowaveAnalogOutputPortDec\x12\x19\n\x0csamplingRate\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1e\n\x11\x66ullScalePowerDbm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04\x62\x61nd\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x12\n\x05\x64\x65lay\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x16\n\tshareable\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x66\n\x0cupconverters\x18\x06 \x03(\x0b\x32L.qm.grpc.qua_config.QuaConfig.MicrowaveAnalogOutputPortDec.UpconvertersEntryB\x02\x18\x01\x12i\n\x0fupconverters_v2\x18\x07 \x01(\x0b\x32P.qm.grpc.qua_config.QuaConfig.MicrowaveAnalogOutputPortDec.UpConvertersContainer\x1ag\n\x11UpconvertersEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.UpConverterConfigDec:\x02\x38\x01\x1a\xe5\x01\n\x15UpConvertersContainer\x12j\n\x05value\x18\x01 \x03(\x0b\x32[.qm.grpc.qua_config.QuaConfig.MicrowaveAnalogOutputPortDec.UpConvertersContainer.ValueEntry\x1a`\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.UpConverterConfigDec:\x02\x38\x01\x42\x0f\n\r_samplingRateB\x14\n\x12_fullScalePowerDbmB\x07\n\x05_bandB\x08\n\x06_delayB\x0c\n\n_shareable\x1a)\n\x14UpConverterConfigDec\x12\x11\n\tfrequency\x18\x01 \x01(\x01\x1a\x81\x03\n\x1bMicrowaveAnalogInputPortDec\x12\x19\n\x0csamplingRate\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x14\n\x07gain_db\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\tshareable\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x11\n\x04\x62\x61nd\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12K\n\rdownconverter\x18\x05 \x01(\x0b\x32\x34.qm.grpc.qua_config.QuaConfig.DownConverterConfigDec\x12V\n\x07lo_mode\x18\x06 \x01(\x0e\x32@.qm.grpc.qua_config.QuaConfig.MicrowaveAnalogInputPortDec.LoModeH\x04\x88\x01\x01\"!\n\x06LoMode\x12\x08\n\x04\x41UTO\x10\x00\x12\r\n\tALWAYS_ON\x10\x01\x42\x0f\n\r_samplingRateB\n\n\x08_gain_dbB\x0c\n\n_shareableB\x07\n\x05_bandB\n\n\x08_lo_mode\x1a+\n\x16\x44ownConverterConfigDec\x12\x11\n\tfrequency\x18\x01 \x01(\x01\x1a\x9b\x0b\n\x1aOctoDacAnalogOutputPortDec\x12\x13\n\x06offset\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x44\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x34.qm.grpc.qua_config.QuaConfig.AnalogOutputPortFilter\x12\x12\n\x05\x64\x65lay\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tshareable\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12^\n\tcrosstalk\x18\x06 \x03(\x0b\x32G.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec.CrosstalkEntryB\x02\x18\x01\x12\x61\n\rsampling_rate\x18\x07 \x01(\x0e\x32\x45.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec.SamplingRateH\x03\x88\x01\x01\x12g\n\x0fupsampling_mode\x18\x08 \x01(\x0e\x32I.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec.SamplingRateModeH\x04\x88\x01\x01\x12]\n\x0boutput_mode\x18\t \x01(\x0e\x32\x43.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec.OutputModeH\x05\x88\x01\x01\x12\x61\n\x0c\x63rosstalk_v2\x18\n \x01(\x0b\x32K.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec.CrosstalkContainer\x12n\n\x11min_voltage_limit\x18\x0b \x01(\x0b\x32N.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec.VoltageLimitContainerH\x06\x88\x01\x01\x12n\n\x11max_voltage_limit\x18\x0c \x01(\x0b\x32N.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec.VoltageLimitContainerH\x07\x88\x01\x01\x1a\x30\n\x0e\x43rosstalkEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\xa9\x01\n\x12\x43rosstalkContainer\x12\x65\n\x05value\x18\x01 \x03(\x0b\x32V.qm.grpc.qua_config.QuaConfig.OctoDacAnalogOutputPortDec.CrosstalkContainer.ValueEntry\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x35\n\x15VoltageLimitContainer\x12\x12\n\x05value\x18\x01 \x01(\x01H\x00\x88\x01\x01\x42\x08\n\x06_value\"\'\n\nOutputMode\x12\n\n\x06\x64irect\x10\x00\x12\r\n\tamplified\x10\x01\"3\n\x0cSamplingRate\x12\r\n\tUndefined\x10\x00\x12\t\n\x05GSPS1\x10\x01\x12\t\n\x05GSPS2\x10\x02\"0\n\x10SamplingRateMode\x12\t\n\x05unset\x10\x00\x12\x06\n\x02mw\x10\x01\x12\t\n\x05pulse\x10\x02\x42\t\n\x07_offsetB\x08\n\x06_delayB\x0c\n\n_shareableB\x10\n\x0e_sampling_rateB\x12\n\x10_upsampling_modeB\x0e\n\x0c_output_modeB\x14\n\x12_min_voltage_limitB\x14\n\x12_max_voltage_limit\x1a\x41\n\x15\x45xponentialParameters\x12\x11\n\tamplitude\x18\x01 \x01(\x01\x12\x15\n\rtime_constant\x18\x02 \x01(\x01\x1a\x9d\x05\n\tIirFilter\x12L\n\x0b\x65xponential\x18\x01 \x03(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.ExponentialParametersB\x02\x18\x01\x12\x1a\n\thigh_pass\x18\x02 \x01(\x01\x42\x02\x18\x01H\x00\x88\x01\x01\x12^\n\x0e\x65xponential_v2\x18\x03 \x01(\x0b\x32\x46.qm.grpc.qua_config.QuaConfig.IirFilter.ExponentialParametersContainer\x12T\n\x0chigh_pass_v2\x18\x04 \x01(\x0b\x32\x39.qm.grpc.qua_config.QuaConfig.IirFilter.HighPassContainerH\x01\x88\x01\x01\x12\x64\n\x13\x65xponential_dc_gain\x18\x05 \x01(\x0b\x32\x42.qm.grpc.qua_config.QuaConfig.IirFilter.ExponentialDcGainContainerH\x02\x88\x01\x01\x1a\x64\n\x1e\x45xponentialParametersContainer\x12\x42\n\x05value\x18\x01 \x03(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.ExponentialParameters\x1a\x31\n\x11HighPassContainer\x12\x12\n\x05value\x18\x01 \x01(\x01H\x00\x88\x01\x01\x42\x08\n\x06_value\x1a:\n\x1a\x45xponentialDcGainContainer\x12\x12\n\x05value\x18\x01 \x01(\x01H\x00\x88\x01\x01\x42\x08\n\x06_valueB\x0c\n\n_high_passB\x0f\n\r_high_pass_v2B\x16\n\x14_exponential_dc_gain\x1a\x83\x02\n\x16\x41nalogOutputPortFilter\x12\x17\n\x0b\x66\x65\x65\x64\x66orward\x18\x01 \x03(\x01\x42\x02\x18\x01\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x03(\x01\x12\x34\n\x03iir\x18\x03 \x01(\x0b\x32\'.qm.grpc.qua_config.QuaConfig.IirFilter\x12\x61\n\x0e\x66\x65\x65\x64\x66orward_v2\x18\x04 \x01(\x0b\x32I.qm.grpc.qua_config.QuaConfig.AnalogOutputPortFilter.FeedforwardContainer\x1a%\n\x14\x46\x65\x65\x64\x66orwardContainer\x12\r\n\x05value\x18\x01 \x03(\x01\x1a\xc3\x01\n\x12\x41nalogInputPortDec\x12\x13\n\x06offset\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x30\n\x06gainDb\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueH\x01\x88\x01\x01\x12\x16\n\tshareable\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0csamplingRate\x18\x04 \x01(\x01H\x03\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_gainDbB\x0c\n\n_shareableB\x0f\n\r_samplingRate\x1a\xaa\x01\n\x14\x44igitalOutputPortDec\x12\x16\n\tshareable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x15\n\x08inverted\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12>\n\x05level\x18\x03 \x01(\x0e\x32*.qm.grpc.qua_config.QuaConfig.VoltageLevelH\x02\x88\x01\x01\x42\x0c\n\n_shareableB\x0b\n\t_invertedB\x08\n\x06_level\x1a\xd4\x02\n\x13\x44igitalInputPortDec\x12\x15\n\x08\x64\x65\x61\x64time\x18\x01 \x01(\rH\x00\x88\x01\x01\x12Q\n\x08polarity\x18\x02 \x01(\x0e\x32:.qm.grpc.qua_config.QuaConfig.DigitalInputPortDec.PolarityH\x01\x88\x01\x01\x12\x16\n\tthreshold\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x16\n\tshareable\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12>\n\x05level\x18\x05 \x01(\x0e\x32*.qm.grpc.qua_config.QuaConfig.VoltageLevelH\x04\x88\x01\x01\"#\n\x08Polarity\x12\n\n\x06RISING\x10\x00\x12\x0b\n\x07\x46\x41LLING\x10\x01\x42\x0b\n\t_deadtimeB\x0b\n\t_polarityB\x0c\n\n_thresholdB\x0c\n\n_shareableB\x08\n\x06_level\x1aM\n\x08MixerRef\x12\r\n\x05mixer\x18\x01 \x01(\t\x12\x17\n\x0bloFrequency\x18\x02 \x01(\x04\x42\x02\x18\x01\x12\x19\n\x11loFrequencyDouble\x18\x03 \x01(\x01\x1a\xa8\x01\n\nOscillator\x12>\n\x15intermediateFrequency\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\x12\x35\n\x05mixer\x18\x02 \x01(\x0b\x32&.qm.grpc.qua_config.QuaConfig.MixerRef\x12#\n\x1bintermediateFrequencyDouble\x18\x03 \x01(\x01\x1aK\n\x0bSingleInput\x12<\n\x04port\x18\x01 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x1a\xc4\x01\n\tMixInputs\x12\x39\n\x01I\x18\x01 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x12\x39\n\x01Q\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x12\r\n\x05mixer\x18\x03 \x01(\t\x12\x17\n\x0bloFrequency\x18\x04 \x01(\x04\x42\x02\x18\x01\x12\x19\n\x11loFrequencyDouble\x18\x05 \x01(\x01\x1a\xc7\x01\n\x15SingleInputCollection\x12O\n\x06inputs\x18\x01 \x03(\x0b\x32?.qm.grpc.qua_config.QuaConfig.SingleInputCollection.InputsEntry\x1a]\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference:\x02\x38\x01\x1a\xb9\x01\n\x0eMultipleInputs\x12H\n\x06inputs\x18\x01 \x03(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.MultipleInputs.InputsEntry\x1a]\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference:\x02\x38\x01\x1a\x39\n\x14GeneralPortReference\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x1a\xd4\x01\n\x0fMultipleOutputs\x12Z\n\x0fport_references\x18\x01 \x03(\x0b\x32\x41.qm.grpc.qua_config.QuaConfig.MultipleOutputs.PortReferencesEntry\x1a\x65\n\x13PortReferencesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.AdcPortReference:\x02\x38\x01\x1a\x99\x13\n\nElementDec\x12J\n\x07outputs\x18\x03 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.ElementDec.OutputsEntryB\x02\x18\x01\x12R\n\rdigitalInputs\x18\x04 \x03(\x0b\x32;.qm.grpc.qua_config.QuaConfig.ElementDec.DigitalInputsEntry\x12T\n\x0e\x64igitalOutputs\x18\t \x03(\x0b\x32<.qm.grpc.qua_config.QuaConfig.ElementDec.DigitalOutputsEntry\x12H\n\x08RFInputs\x18\n \x03(\x0b\x32\x36.qm.grpc.qua_config.QuaConfig.ElementDec.RFInputsEntry\x12J\n\tRFOutputs\x18\x0b \x03(\x0b\x32\x37.qm.grpc.qua_config.QuaConfig.ElementDec.RFOutputsEntry\x12@\n\x0bsingleInput\x18\x05 \x01(\x0b\x32).qm.grpc.qua_config.QuaConfig.SingleInputH\x00\x12<\n\tmixInputs\x18\x06 \x01(\x0b\x32\'.qm.grpc.qua_config.QuaConfig.MixInputsH\x00\x12T\n\x15singleInputCollection\x18\x32 \x01(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.SingleInputCollectionH\x00\x12\x46\n\x0emultipleInputs\x18\x33 \x01(\x0b\x32,.qm.grpc.qua_config.QuaConfig.MultipleInputsH\x00\x12S\n\x0emicrowaveInput\x18\x34 \x01(\x0b\x32\x39.qm.grpc.qua_config.QuaConfig.MicrowaveInputPortReferenceH\x00\x12U\n\x0fmicrowaveOutput\x18\x35 \x01(\x0b\x32:.qm.grpc.qua_config.QuaConfig.MicrowaveOutputPortReferenceH\x01\x12H\n\x0fmultipleOutputs\x18\x36 \x01(\x0b\x32-.qm.grpc.qua_config.QuaConfig.MultipleOutputsH\x01\x12\x32\n\x0ctimeOfFlight\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\x08smearing\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x15intermediateFrequency\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x02\x18\x01\x12#\n\x1bintermediateFrequencyDouble\x18\x18 \x01(\x01\x12%\n\x1dintermediateFrequencyNegative\x18\x17 \x01(\x08\x12L\n\noperations\x18\x15 \x03(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.ElementDec.OperationsEntry\x12\x33\n\rmeasurementQe\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12R\n\x15outputPulseParameters\x18\x1e \x01(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.OutputPulseParameters\x12@\n\nholdOffset\x18\x1f \x01(\x0b\x32(.qm.grpc.qua_config.QuaConfig.HoldOffsetB\x02\x18\x01\x12\x34\n\x06sticky\x18  \x01(\x0b\x32$.qm.grpc.qua_config.QuaConfig.Sticky\x12;\n\x06thread\x18( \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.ElementThread\x12J\n\x1fintermediateFrequencyOscillator\x18= \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01H\x02\x12\x33\n%intermediateFrequencyOscillatorDouble\x18@ \x01(\x01\x42\x02\x18\x01H\x02\x12\x37\n\x0fnamedOscillator\x18> \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x02\x12.\n\x0cnoOscillator\x18? \x01(\x0b\x32\x16.google.protobuf.EmptyH\x02\x1a^\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.AdcPortReference:\x02\x38\x01\x1am\n\x12\x44igitalInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.qm.grpc.qua_config.QuaConfig.DigitalInputPortReference:\x02\x38\x01\x1ao\n\x13\x44igitalOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x38.qm.grpc.qua_config.QuaConfig.DigitalOutputPortReference:\x02\x38\x01\x1a\x63\n\rRFInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.GeneralPortReference:\x02\x38\x01\x1a\x64\n\x0eRFOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.GeneralPortReference:\x02\x38\x01\x1a\x31\n\x0fOperationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x17\n\x15\x65lement_inputs_one_ofB\x18\n\x16\x65lement_outputs_one_ofB\x13\n\x11oscillator_one_of\x1a#\n\rElementThread\x12\x12\n\nthreadName\x18\x01 \x01(\t\x1a\xd2\x02\n\x15OutputPulseParameters\x12\x15\n\tthreshold\x18\x01 \x01(\rB\x02\x18\x01\x12\x11\n\x05table\x18\x02 \x03(\rB\x02\x18\x01\x12\x17\n\x0fsignalThreshold\x18\x03 \x01(\x05\x12T\n\x0esignalPolarity\x18\x04 \x01(\x0e\x32<.qm.grpc.qua_config.QuaConfig.OutputPulseParameters.Polarity\x12\x1b\n\x13\x64\x65rivativeThreshold\x18\x05 \x01(\x05\x12X\n\x12\x64\x65rivativePolarity\x18\x06 \x01(\x0e\x32<.qm.grpc.qua_config.QuaConfig.OutputPulseParameters.Polarity\")\n\x08Polarity\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\x1a\x1e\n\nHoldOffset\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x1a;\n\x06Sticky\x12\x0e\n\x06\x61nalog\x18\x01 \x01(\x08\x12\x0f\n\x07\x64igital\x18\x02 \x01(\x08\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x1a\x43\n\x10\x44\x61\x63PortReference\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x0b\n\x03\x66\x65m\x18\x03 \x01(\r\x1a\x43\n\x10\x41\x64\x63PortReference\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x0b\n\x03\x66\x65m\x18\x03 \x01(\r\x1au\n\x19\x44igitalInputPortReference\x12\x39\n\x04port\x18\x01 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.PortReference\x12\r\n\x05\x64\x65lay\x18\x02 \x01(\r\x12\x0e\n\x06\x62uffer\x18\x03 \x01(\r\x1aW\n\x1a\x44igitalOutputPortReference\x12\x39\n\x04port\x18\x01 \x01(\x0b\x32+.qm.grpc.qua_config.QuaConfig.PortReference\x1a@\n\rPortReference\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x0b\n\x03\x66\x65m\x18\x03 \x01(\r\x1ap\n\x1bMicrowaveInputPortReference\x12<\n\x04port\x18\x01 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x12\x13\n\x0bupconverter\x18\x03 \x01(\r\x1a\\\n\x1cMicrowaveOutputPortReference\x12<\n\x04port\x18\x01 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.AdcPortReference\x1a\xa0\x03\n\x08PulseDec\x12\x0e\n\x06length\x18\x02 \x01(\r\x12\x11\n\toperation\x18\x03 \x01(\r\x12H\n\twaveforms\x18\x04 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.PulseDec.WaveformsEntry\x12\x33\n\rdigitalMarker\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x12integrationWeights\x18\x08 \x03(\x0b\x32>.qm.grpc.qua_config.QuaConfig.PulseDec.IntegrationWeightsEntry\x1a\x30\n\x0eWaveformsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17IntegrationWeightsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\tOperation\x12\x0f\n\x0bMEASUREMENT\x10\x00\x12\x0b\n\x07\x43ONTROL\x10\x01\x1a\xbf\x02\n\x0bWaveformDec\x12G\n\tarbitrary\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.ArbitraryWaveformDecH\x00\x12\x45\n\x08\x63onstant\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua_config.QuaConfig.ConstantWaveformDecH\x00\x12M\n\ncompressed\x18\x03 \x01(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.CompressedWaveformDecB\x02\x18\x01H\x00\x12?\n\x05\x61rray\x18\x04 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.WaveformArrayDecH\x00\x42\x10\n\x0ewaveform_oneof\x1a\xe4\x01\n\x14\x41rbitraryWaveformDec\x12\x0f\n\x07samples\x18\x01 \x03(\x01\x12\x12\n\nmultiplier\x18\x02 \x01(\x01\x12%\n\x19\x64\x65precatedMaxAllowedError\x18\x03 \x01(\x01\x42\x02\x18\x01\x12\x35\n\x0fmaxAllowedError\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0csamplingRate\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x15\n\risOverridable\x18\x06 \x01(\x08\x1a\x39\n\x13\x43onstantWaveformDec\x12\x0e\n\x06sample\x18\x01 \x01(\x01\x12\x12\n\nmultiplier\x18\x02 \x01(\x01\x1aX\n\x10WaveformArrayDec\x12\x44\n\rsamples_array\x18\x01 \x03(\x0b\x32-.qm.grpc.qua_config.QuaConfig.WaveformSamples\x1a\"\n\x0fWaveformSamples\x12\x0f\n\x07samples\x18\x01 \x03(\x01\x1a<\n\x15\x43ompressedWaveformDec\x12\x0f\n\x07samples\x18\x01 \x03(\x01\x12\x12\n\nsampleRate\x18\x02 \x01(\x01\x1aZ\n\x12\x44igitalWaveformDec\x12\x44\n\x07samples\x18\x01 \x03(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.DigitalWaveformSample\x1a\x36\n\x15\x44igitalWaveformSample\x12\r\n\x05value\x18\x01 \x01(\x08\x12\x0e\n\x06length\x18\x02 \x01(\r\x1aM\n\x08MixerDec\x12\x41\n\ncorrection\x18\x01 \x03(\x0b\x32-.qm.grpc.qua_config.QuaConfig.CorrectionEntry\x1a\xa2\x01\n\x14IntegrationWeightDec\x12\x45\n\x06\x63osine\x18\x01 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.IntegrationWeightSample\x12\x43\n\x04sine\x18\x02 \x03(\x0b\x32\x35.qm.grpc.qua_config.QuaConfig.IntegrationWeightSample\x1a\x38\n\x17IntegrationWeightSample\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0e\n\x06length\x18\x02 \x01(\r\x1a\xca\x01\n\x0f\x43orrectionEntry\x12\x15\n\tfrequency\x18\x01 \x01(\x04\x42\x02\x18\x01\x12\x17\n\x0bloFrequency\x18\x02 \x01(\x04\x42\x02\x18\x01\x12\x38\n\ncorrection\x18\x03 \x01(\x0b\x32$.qm.grpc.qua_config.QuaConfig.Matrix\x12\x19\n\x11\x66requencyNegative\x18\x04 \x01(\x08\x12\x17\n\x0f\x66requencyDouble\x18\x05 \x01(\x01\x12\x19\n\x11loFrequencyDouble\x18\x06 \x01(\x01\x1a<\n\x06Matrix\x12\x0b\n\x03v00\x18\x01 \x01(\x01\x12\x0b\n\x03v01\x18\x02 \x01(\x01\x12\x0b\n\x03v10\x18\x03 \x01(\x01\x12\x0b\n\x03v11\x18\x04 \x01(\x01\x1a\x81\x12\n\x06Octave\x1a\xfe\x03\n\x06\x43onfig\x12@\n\tloopbacks\x18\x01 \x03(\x0b\x32-.qm.grpc.qua_config.QuaConfig.Octave.Loopback\x12N\n\nrf_outputs\x18\x02 \x03(\x0b\x32:.qm.grpc.qua_config.QuaConfig.Octave.Config.RfOutputsEntry\x12L\n\trf_inputs\x18\x03 \x03(\x0b\x32\x39.qm.grpc.qua_config.QuaConfig.Octave.Config.RfInputsEntry\x12H\n\nif_outputs\x18\x04 \x01(\x0b\x32\x34.qm.grpc.qua_config.QuaConfig.Octave.IFOutputsConfig\x1a\x65\n\x0eRfOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x33.qm.grpc.qua_config.QuaConfig.Octave.RFOutputConfig:\x02\x38\x01\x1a\x63\n\rRfInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua_config.QuaConfig.Octave.RFInputConfig:\x02\x38\x01\x1a\xaa\x01\n\x08Loopback\x12K\n\x0flo_source_input\x18\x01 \x01(\x0e\x32\x32.qm.grpc.qua_config.QuaConfig.Octave.LoopbackInput\x12Q\n\x13lo_source_generator\x18\x02 \x01(\x0b\x32\x34.qm.grpc.qua_config.QuaConfig.Octave.SynthesizerPort\x1au\n\x0fSynthesizerPort\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12M\n\tport_name\x18\x02 \x01(\x0e\x32:.qm.grpc.qua_config.QuaConfig.Octave.SynthesizerOutputName\x1a\xef\x02\n\x0eRFOutputConfig\x12\x14\n\x0cLO_frequency\x18\x01 \x01(\x01\x12\x45\n\tLO_source\x18\x02 \x01(\x0e\x32\x32.qm.grpc.qua_config.QuaConfig.Octave.LOSourceInput\x12K\n\x0boutput_mode\x18\x03 \x01(\x0e\x32\x36.qm.grpc.qua_config.QuaConfig.Octave.OutputSwitchState\x12\x0c\n\x04gain\x18\x04 \x01(\x02\x12\x19\n\x11input_attenuators\x18\x05 \x01(\x08\x12\x44\n\x0cI_connection\x18\x06 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x12\x44\n\x0cQ_connection\x18\x07 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.DacPortReference\x1a\xbb\x02\n\rRFInputConfig\x12M\n\tRF_source\x18\x01 \x01(\x0e\x32:.qm.grpc.qua_config.QuaConfig.Octave.DownconverterRFSource\x12\x14\n\x0cLO_frequency\x18\x02 \x01(\x01\x12\x45\n\tLO_source\x18\x03 \x01(\x0e\x32\x32.qm.grpc.qua_config.QuaConfig.Octave.LOSourceInput\x12>\n\tIF_mode_I\x18\x04 \x01(\x0e\x32+.qm.grpc.qua_config.QuaConfig.Octave.IFMode\x12>\n\tIF_mode_Q\x18\x05 \x01(\x0e\x32+.qm.grpc.qua_config.QuaConfig.Octave.IFMode\x1a\x62\n\x14SingleIFOutputConfig\x12<\n\x04port\x18\x01 \x01(\x0b\x32..qm.grpc.qua_config.QuaConfig.AdcPortReference\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\xa9\x01\n\x0fIFOutputsConfig\x12J\n\x07IF_out1\x18\x01 \x01(\x0b\x32\x39.qm.grpc.qua_config.QuaConfig.Octave.SingleIFOutputConfig\x12J\n\x07IF_out2\x18\x02 \x01(\x0b\x32\x39.qm.grpc.qua_config.QuaConfig.Octave.SingleIFOutputConfig\"S\n\x15SynthesizerOutputName\x12\n\n\x06synth1\x10\x00\x12\n\n\x06synth2\x10\x01\x12\n\n\x06synth3\x10\x02\x12\n\n\x06synth4\x10\x03\x12\n\n\x06synth5\x10\x04\"F\n\rLOSourceInput\x12\x0b\n\x07not_set\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x12\x0c\n\x08\x61nalyzer\x10\x03\"c\n\rLoopbackInput\x12\r\n\tundefined\x10\x00\x12\x07\n\x03LO1\x10\x01\x12\x07\n\x03LO2\x10\x02\x12\x07\n\x03LO3\x10\x03\x12\x07\n\x03LO4\x10\x04\x12\x07\n\x03LO5\x10\x05\x12\n\n\x06\x44md1LO\x10\x06\x12\n\n\x06\x44md2LO\x10\x07\"r\n\x15\x44ownconverterRFSource\x12\t\n\x05rf_in\x10\x00\x12\x0e\n\nloopback_1\x10\x01\x12\x0e\n\nloopback_2\x10\x02\x12\x0e\n\nloopback_3\x10\x03\x12\x0e\n\nloopback_4\x10\x04\x12\x0e\n\nloopback_5\x10\x05\"d\n\x11OutputSwitchState\x12\t\n\x05unset\x10\x00\x12\r\n\talways_on\x10\x01\x12\x0e\n\nalways_off\x10\x02\x12\r\n\ttriggered\x10\x03\x12\x16\n\x12triggered_reversed\x10\x04\"6\n\x06IFMode\x12\n\n\x06\x64irect\x10\x00\x12\t\n\x05mixer\x10\x01\x12\x0c\n\x08\x65nvelope\x10\x02\x12\x07\n\x03off\x10\x03\"\"\n\x0cVoltageLevel\x12\t\n\x05LVTTL\x10\x00\x12\x07\n\x03TTL\x10\x01\"d\n\x11OutputSwitchState\x12\t\n\x05unset\x10\x00\x12\r\n\talways_on\x10\x01\x12\x0e\n\nalways_off\x10\x02\x12\r\n\ttriggered\x10\x03\x12\x16\n\x12triggered_reversed\x10\x04\x42\x10\n\x0e\x63onfig_versionJ\x04\x08\x03\x10\x0b\x42\x02P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qm.pb.inc_qua_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_CONTROLDEVICESENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_CONTROLDEVICESENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_ELEMENTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_ELEMENTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_PULSESENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_PULSESENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_MIXERSENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_MIXERSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1_OCTAVESENTRY']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1_OCTAVESENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_QUACONFIGV1'].fields_by_name['controllers']._loaded_options = None
  _globals['_QUACONFIG_QUACONFIGV1'].fields_by_name['controllers']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_CONTROLLERCONFIG_CONTROLDEVICESENTRY']._loaded_options = None
  _globals['_QUACONFIG_CONTROLLERCONFIG_CONTROLDEVICESENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_CONTROLLERCONFIG_MIXERSENTRY']._loaded_options = None
  _globals['_QUACONFIG_CONTROLLERCONFIG_MIXERSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_CONTROLLERCONFIG_OCTAVESENTRY']._loaded_options = None
  _globals['_QUACONFIG_CONTROLLERCONFIG_OCTAVESENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_LOGICALCONFIG_ELEMENTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_LOGICALCONFIG_ELEMENTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_LOGICALCONFIG_OSCILLATORSENTRY']._loaded_options = None
  _globals['_QUACONFIG_LOGICALCONFIG_OSCILLATORSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_LOGICALCONFIG_PULSESENTRY']._loaded_options = None
  _globals['_QUACONFIG_LOGICALCONFIG_PULSESENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_LOGICALCONFIG_WAVEFORMSENTRY']._loaded_options = None
  _globals['_QUACONFIG_LOGICALCONFIG_WAVEFORMSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_LOGICALCONFIG_DIGITALWAVEFORMSENTRY']._loaded_options = None
  _globals['_QUACONFIG_LOGICALCONFIG_DIGITALWAVEFORMSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_LOGICALCONFIG_INTEGRATIONWEIGHTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_LOGICALCONFIG_INTEGRATIONWEIGHTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_DEVICEDEC_FEMSENTRY']._loaded_options = None
  _globals['_QUACONFIG_DEVICEDEC_FEMSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_OCTODACFEMDEC_ANALOGOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_OCTODACFEMDEC_ANALOGOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_OCTODACFEMDEC_ANALOGINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_OCTODACFEMDEC_ANALOGINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_OCTODACFEMDEC_DIGITALOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_OCTODACFEMDEC_DIGITALOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_OCTODACFEMDEC_DIGITALINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_OCTODACFEMDEC_DIGITALINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_MICROWAVEFEMDEC_ANALOGOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_MICROWAVEFEMDEC_ANALOGOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_MICROWAVEFEMDEC_ANALOGINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_MICROWAVEFEMDEC_ANALOGINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_MICROWAVEFEMDEC_DIGITALOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_MICROWAVEFEMDEC_DIGITALOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_MICROWAVEFEMDEC_DIGITALINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_MICROWAVEFEMDEC_DIGITALINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC_CROSSTALKENTRY']._loaded_options = None
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC_CROSSTALKENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC'].fields_by_name['channelWeights']._loaded_options = None
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC'].fields_by_name['channelWeights']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSENTRY']._loaded_options = None
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSCONTAINER_VALUEENTRY']._loaded_options = None
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSCONTAINER_VALUEENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC'].fields_by_name['upconverters']._loaded_options = None
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC'].fields_by_name['upconverters']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKENTRY']._loaded_options = None
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKCONTAINER_VALUEENTRY']._loaded_options = None
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKCONTAINER_VALUEENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC'].fields_by_name['crosstalk']._loaded_options = None
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC'].fields_by_name['crosstalk']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_IIRFILTER'].fields_by_name['exponential']._loaded_options = None
  _globals['_QUACONFIG_IIRFILTER'].fields_by_name['exponential']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_IIRFILTER'].fields_by_name['high_pass']._loaded_options = None
  _globals['_QUACONFIG_IIRFILTER'].fields_by_name['high_pass']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_ANALOGOUTPUTPORTFILTER'].fields_by_name['feedforward']._loaded_options = None
  _globals['_QUACONFIG_ANALOGOUTPUTPORTFILTER'].fields_by_name['feedforward']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_MIXERREF'].fields_by_name['loFrequency']._loaded_options = None
  _globals['_QUACONFIG_MIXERREF'].fields_by_name['loFrequency']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_OSCILLATOR'].fields_by_name['intermediateFrequency']._loaded_options = None
  _globals['_QUACONFIG_OSCILLATOR'].fields_by_name['intermediateFrequency']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_MIXINPUTS'].fields_by_name['loFrequency']._loaded_options = None
  _globals['_QUACONFIG_MIXINPUTS'].fields_by_name['loFrequency']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_MULTIPLEOUTPUTS_PORTREFERENCESENTRY']._loaded_options = None
  _globals['_QUACONFIG_MULTIPLEOUTPUTS_PORTREFERENCESENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ELEMENTDEC_RFINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC_RFINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ELEMENTDEC_RFOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC_RFOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ELEMENTDEC_OPERATIONSENTRY']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC_OPERATIONSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['outputs']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['outputs']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['intermediateFrequency']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['intermediateFrequency']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['holdOffset']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['holdOffset']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['intermediateFrequencyOscillator']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['intermediateFrequencyOscillator']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['intermediateFrequencyOscillatorDouble']._loaded_options = None
  _globals['_QUACONFIG_ELEMENTDEC'].fields_by_name['intermediateFrequencyOscillatorDouble']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_OUTPUTPULSEPARAMETERS'].fields_by_name['threshold']._loaded_options = None
  _globals['_QUACONFIG_OUTPUTPULSEPARAMETERS'].fields_by_name['threshold']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_OUTPUTPULSEPARAMETERS'].fields_by_name['table']._loaded_options = None
  _globals['_QUACONFIG_OUTPUTPULSEPARAMETERS'].fields_by_name['table']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_PULSEDEC_WAVEFORMSENTRY']._loaded_options = None
  _globals['_QUACONFIG_PULSEDEC_WAVEFORMSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_WAVEFORMDEC'].fields_by_name['compressed']._loaded_options = None
  _globals['_QUACONFIG_WAVEFORMDEC'].fields_by_name['compressed']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_ARBITRARYWAVEFORMDEC'].fields_by_name['deprecatedMaxAllowedError']._loaded_options = None
  _globals['_QUACONFIG_ARBITRARYWAVEFORMDEC'].fields_by_name['deprecatedMaxAllowedError']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_CORRECTIONENTRY'].fields_by_name['frequency']._loaded_options = None
  _globals['_QUACONFIG_CORRECTIONENTRY'].fields_by_name['frequency']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_CORRECTIONENTRY'].fields_by_name['loFrequency']._loaded_options = None
  _globals['_QUACONFIG_CORRECTIONENTRY'].fields_by_name['loFrequency']._serialized_options = b'\030\001'
  _globals['_QUACONFIG_OCTAVE_CONFIG_RFOUTPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_OCTAVE_CONFIG_RFOUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG_OCTAVE_CONFIG_RFINPUTSENTRY']._loaded_options = None
  _globals['_QUACONFIG_OCTAVE_CONFIG_RFINPUTSENTRY']._serialized_options = b'8\001'
  _globals['_QUACONFIG']._serialized_start=113
  _globals['_QUACONFIG']._serialized_end=20782
  _globals['_QUACONFIG_QUACONFIGV1']._serialized_start=263
  _globals['_QUACONFIG_QUACONFIGV1']._serialized_end=2038
  _globals['_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY']._serialized_start=1084
  _globals['_QUACONFIG_QUACONFIGV1_CONTROLLERSENTRY']._serialized_end=1179
  _globals['_QUACONFIG_QUACONFIGV1_CONTROLDEVICESENTRY']._serialized_start=1181
  _globals['_QUACONFIG_QUACONFIGV1_CONTROLDEVICESENTRY']._serialized_end=1275
  _globals['_QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY']._serialized_start=1277
  _globals['_QUACONFIG_QUACONFIGV1_OSCILLATORSENTRY']._serialized_end=1369
  _globals['_QUACONFIG_QUACONFIGV1_ELEMENTSENTRY']._serialized_start=1371
  _globals['_QUACONFIG_QUACONFIGV1_ELEMENTSENTRY']._serialized_end=1460
  _globals['_QUACONFIG_QUACONFIGV1_PULSESENTRY']._serialized_start=1462
  _globals['_QUACONFIG_QUACONFIGV1_PULSESENTRY']._serialized_end=1547
  _globals['_QUACONFIG_QUACONFIGV1_MIXERSENTRY']._serialized_start=1549
  _globals['_QUACONFIG_QUACONFIGV1_MIXERSENTRY']._serialized_end=1634
  _globals['_QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY']._serialized_start=1636
  _globals['_QUACONFIG_QUACONFIGV1_WAVEFORMSENTRY']._serialized_end=1727
  _globals['_QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY']._serialized_start=1729
  _globals['_QUACONFIG_QUACONFIGV1_DIGITALWAVEFORMSENTRY']._serialized_end=1834
  _globals['_QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY']._serialized_start=1836
  _globals['_QUACONFIG_QUACONFIGV1_INTEGRATIONWEIGHTSENTRY']._serialized_end=1945
  _globals['_QUACONFIG_QUACONFIGV1_OCTAVESENTRY']._serialized_start=1947
  _globals['_QUACONFIG_QUACONFIGV1_OCTAVESENTRY']._serialized_end=2038
  _globals['_QUACONFIG_QUACONFIGV2']._serialized_start=2041
  _globals['_QUACONFIG_QUACONFIGV2']._serialized_end=2198
  _globals['_QUACONFIG_CONTROLLERCONFIG']._serialized_start=2201
  _globals['_QUACONFIG_CONTROLLERCONFIG']._serialized_end=2741
  _globals['_QUACONFIG_CONTROLLERCONFIG_CONTROLDEVICESENTRY']._serialized_start=1181
  _globals['_QUACONFIG_CONTROLLERCONFIG_CONTROLDEVICESENTRY']._serialized_end=1275
  _globals['_QUACONFIG_CONTROLLERCONFIG_MIXERSENTRY']._serialized_start=1549
  _globals['_QUACONFIG_CONTROLLERCONFIG_MIXERSENTRY']._serialized_end=1634
  _globals['_QUACONFIG_CONTROLLERCONFIG_OCTAVESENTRY']._serialized_start=1947
  _globals['_QUACONFIG_CONTROLLERCONFIG_OCTAVESENTRY']._serialized_end=2038
  _globals['_QUACONFIG_LOGICALCONFIG']._serialized_start=2744
  _globals['_QUACONFIG_LOGICALCONFIG']._serialized_end=3844
  _globals['_QUACONFIG_LOGICALCONFIG_ELEMENTSENTRY']._serialized_start=1371
  _globals['_QUACONFIG_LOGICALCONFIG_ELEMENTSENTRY']._serialized_end=1460
  _globals['_QUACONFIG_LOGICALCONFIG_OSCILLATORSENTRY']._serialized_start=1277
  _globals['_QUACONFIG_LOGICALCONFIG_OSCILLATORSENTRY']._serialized_end=1369
  _globals['_QUACONFIG_LOGICALCONFIG_PULSESENTRY']._serialized_start=1462
  _globals['_QUACONFIG_LOGICALCONFIG_PULSESENTRY']._serialized_end=1547
  _globals['_QUACONFIG_LOGICALCONFIG_WAVEFORMSENTRY']._serialized_start=1636
  _globals['_QUACONFIG_LOGICALCONFIG_WAVEFORMSENTRY']._serialized_end=1727
  _globals['_QUACONFIG_LOGICALCONFIG_DIGITALWAVEFORMSENTRY']._serialized_start=1729
  _globals['_QUACONFIG_LOGICALCONFIG_DIGITALWAVEFORMSENTRY']._serialized_end=1834
  _globals['_QUACONFIG_LOGICALCONFIG_INTEGRATIONWEIGHTSENTRY']._serialized_start=1836
  _globals['_QUACONFIG_LOGICALCONFIG_INTEGRATIONWEIGHTSENTRY']._serialized_end=1945
  _globals['_QUACONFIG_DEVICEDEC']._serialized_start=3847
  _globals['_QUACONFIG_DEVICEDEC']._serialized_end=4008
  _globals['_QUACONFIG_DEVICEDEC_FEMSENTRY']._serialized_start=3925
  _globals['_QUACONFIG_DEVICEDEC_FEMSENTRY']._serialized_end=4008
  _globals['_QUACONFIG_FEMTYPES']._serialized_start=4011
  _globals['_QUACONFIG_FEMTYPES']._serialized_end=4233
  _globals['_QUACONFIG_CONTROLLERDEC']._serialized_start=4236
  _globals['_QUACONFIG_CONTROLLERDEC']._serialized_end=5033
  _globals['_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY']._serialized_start=4615
  _globals['_QUACONFIG_CONTROLLERDEC_ANALOGOUTPUTSENTRY']._serialized_end=4718
  _globals['_QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY']._serialized_start=4720
  _globals['_QUACONFIG_CONTROLLERDEC_ANALOGINPUTSENTRY']._serialized_end=4821
  _globals['_QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY']._serialized_start=4823
  _globals['_QUACONFIG_CONTROLLERDEC_DIGITALOUTPUTSENTRY']._serialized_end=4928
  _globals['_QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY']._serialized_start=4930
  _globals['_QUACONFIG_CONTROLLERDEC_DIGITALINPUTSENTRY']._serialized_end=5033
  _globals['_QUACONFIG_OCTODACFEMDEC']._serialized_start=5036
  _globals['_QUACONFIG_OCTODACFEMDEC']._serialized_end=5826
  _globals['_QUACONFIG_OCTODACFEMDEC_ANALOGOUTPUTSENTRY']._serialized_start=5401
  _globals['_QUACONFIG_OCTODACFEMDEC_ANALOGOUTPUTSENTRY']._serialized_end=5511
  _globals['_QUACONFIG_OCTODACFEMDEC_ANALOGINPUTSENTRY']._serialized_start=4720
  _globals['_QUACONFIG_OCTODACFEMDEC_ANALOGINPUTSENTRY']._serialized_end=4821
  _globals['_QUACONFIG_OCTODACFEMDEC_DIGITALOUTPUTSENTRY']._serialized_start=4823
  _globals['_QUACONFIG_OCTODACFEMDEC_DIGITALOUTPUTSENTRY']._serialized_end=4928
  _globals['_QUACONFIG_OCTODACFEMDEC_DIGITALINPUTSENTRY']._serialized_start=4930
  _globals['_QUACONFIG_OCTODACFEMDEC_DIGITALINPUTSENTRY']._serialized_end=5033
  _globals['_QUACONFIG_MICROWAVEFEMDEC']._serialized_start=5829
  _globals['_QUACONFIG_MICROWAVEFEMDEC']._serialized_end=6640
  _globals['_QUACONFIG_MICROWAVEFEMDEC_ANALOGOUTPUTSENTRY']._serialized_start=6204
  _globals['_QUACONFIG_MICROWAVEFEMDEC_ANALOGOUTPUTSENTRY']._serialized_end=6316
  _globals['_QUACONFIG_MICROWAVEFEMDEC_ANALOGINPUTSENTRY']._serialized_start=6318
  _globals['_QUACONFIG_MICROWAVEFEMDEC_ANALOGINPUTSENTRY']._serialized_end=6428
  _globals['_QUACONFIG_MICROWAVEFEMDEC_DIGITALOUTPUTSENTRY']._serialized_start=4823
  _globals['_QUACONFIG_MICROWAVEFEMDEC_DIGITALOUTPUTSENTRY']._serialized_end=4928
  _globals['_QUACONFIG_MICROWAVEFEMDEC_DIGITALINPUTSENTRY']._serialized_start=4930
  _globals['_QUACONFIG_MICROWAVEFEMDEC_DIGITALINPUTSENTRY']._serialized_end=5033
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC']._serialized_start=6643
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC']._serialized_end=7231
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY']._serialized_start=7049
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC_CHANNELWEIGHTSENTRY']._serialized_end=7102
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC_CROSSTALKENTRY']._serialized_start=7104
  _globals['_QUACONFIG_ANALOGOUTPUTPORTDEC_CROSSTALKENTRY']._serialized_end=7152
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC']._serialized_start=7234
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC']._serialized_end=8006
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSENTRY']._serialized_start=7599
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSENTRY']._serialized_end=7702
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSCONTAINER']._serialized_start=7705
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSCONTAINER']._serialized_end=7934
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSCONTAINER_VALUEENTRY']._serialized_start=7838
  _globals['_QUACONFIG_MICROWAVEANALOGOUTPUTPORTDEC_UPCONVERTERSCONTAINER_VALUEENTRY']._serialized_end=7934
  _globals['_QUACONFIG_UPCONVERTERCONFIGDEC']._serialized_start=8008
  _globals['_QUACONFIG_UPCONVERTERCONFIGDEC']._serialized_end=8049
  _globals['_QUACONFIG_MICROWAVEANALOGINPUTPORTDEC']._serialized_start=8052
  _globals['_QUACONFIG_MICROWAVEANALOGINPUTPORTDEC']._serialized_end=8437
  _globals['_QUACONFIG_MICROWAVEANALOGINPUTPORTDEC_LOMODE']._serialized_start=8340
  _globals['_QUACONFIG_MICROWAVEANALOGINPUTPORTDEC_LOMODE']._serialized_end=8373
  _globals['_QUACONFIG_DOWNCONVERTERCONFIGDEC']._serialized_start=8439
  _globals['_QUACONFIG_DOWNCONVERTERCONFIGDEC']._serialized_end=8482
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC']._serialized_start=8485
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC']._serialized_end=9920
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKENTRY']._serialized_start=7104
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKENTRY']._serialized_end=7152
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKCONTAINER']._serialized_start=9419
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKCONTAINER']._serialized_end=9588
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKCONTAINER_VALUEENTRY']._serialized_start=9544
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_CROSSTALKCONTAINER_VALUEENTRY']._serialized_end=9588
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_VOLTAGELIMITCONTAINER']._serialized_start=9590
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_VOLTAGELIMITCONTAINER']._serialized_end=9643
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_OUTPUTMODE']._serialized_start=9645
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_OUTPUTMODE']._serialized_end=9684
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_SAMPLINGRATE']._serialized_start=9686
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_SAMPLINGRATE']._serialized_end=9737
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_SAMPLINGRATEMODE']._serialized_start=9739
  _globals['_QUACONFIG_OCTODACANALOGOUTPUTPORTDEC_SAMPLINGRATEMODE']._serialized_end=9787
  _globals['_QUACONFIG_EXPONENTIALPARAMETERS']._serialized_start=9922
  _globals['_QUACONFIG_EXPONENTIALPARAMETERS']._serialized_end=9987
  _globals['_QUACONFIG_IIRFILTER']._serialized_start=9990
  _globals['_QUACONFIG_IIRFILTER']._serialized_end=10659
  _globals['_QUACONFIG_IIRFILTER_EXPONENTIALPARAMETERSCONTAINER']._serialized_start=10393
  _globals['_QUACONFIG_IIRFILTER_EXPONENTIALPARAMETERSCONTAINER']._serialized_end=10493
  _globals['_QUACONFIG_IIRFILTER_HIGHPASSCONTAINER']._serialized_start=10495
  _globals['_QUACONFIG_IIRFILTER_HIGHPASSCONTAINER']._serialized_end=10544
  _globals['_QUACONFIG_IIRFILTER_EXPONENTIALDCGAINCONTAINER']._serialized_start=10546
  _globals['_QUACONFIG_IIRFILTER_EXPONENTIALDCGAINCONTAINER']._serialized_end=10604
  _globals['_QUACONFIG_ANALOGOUTPUTPORTFILTER']._serialized_start=10662
  _globals['_QUACONFIG_ANALOGOUTPUTPORTFILTER']._serialized_end=10921
  _globals['_QUACONFIG_ANALOGOUTPUTPORTFILTER_FEEDFORWARDCONTAINER']._serialized_start=10884
  _globals['_QUACONFIG_ANALOGOUTPUTPORTFILTER_FEEDFORWARDCONTAINER']._serialized_end=10921
  _globals['_QUACONFIG_ANALOGINPUTPORTDEC']._serialized_start=10924
  _globals['_QUACONFIG_ANALOGINPUTPORTDEC']._serialized_end=11119
  _globals['_QUACONFIG_DIGITALOUTPUTPORTDEC']._serialized_start=11122
  _globals['_QUACONFIG_DIGITALOUTPUTPORTDEC']._serialized_end=11292
  _globals['_QUACONFIG_DIGITALINPUTPORTDEC']._serialized_start=11295
  _globals['_QUACONFIG_DIGITALINPUTPORTDEC']._serialized_end=11635
  _globals['_QUACONFIG_DIGITALINPUTPORTDEC_POLARITY']._serialized_start=11536
  _globals['_QUACONFIG_DIGITALINPUTPORTDEC_POLARITY']._serialized_end=11571
  _globals['_QUACONFIG_MIXERREF']._serialized_start=11637
  _globals['_QUACONFIG_MIXERREF']._serialized_end=11714
  _globals['_QUACONFIG_OSCILLATOR']._serialized_start=11717
  _globals['_QUACONFIG_OSCILLATOR']._serialized_end=11885
  _globals['_QUACONFIG_SINGLEINPUT']._serialized_start=11887
  _globals['_QUACONFIG_SINGLEINPUT']._serialized_end=11962
  _globals['_QUACONFIG_MIXINPUTS']._serialized_start=11965
  _globals['_QUACONFIG_MIXINPUTS']._serialized_end=12161
  _globals['_QUACONFIG_SINGLEINPUTCOLLECTION']._serialized_start=12164
  _globals['_QUACONFIG_SINGLEINPUTCOLLECTION']._serialized_end=12363
  _globals['_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY']._serialized_start=12270
  _globals['_QUACONFIG_SINGLEINPUTCOLLECTION_INPUTSENTRY']._serialized_end=12363
  _globals['_QUACONFIG_MULTIPLEINPUTS']._serialized_start=12366
  _globals['_QUACONFIG_MULTIPLEINPUTS']._serialized_end=12551
  _globals['_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY']._serialized_start=12270
  _globals['_QUACONFIG_MULTIPLEINPUTS_INPUTSENTRY']._serialized_end=12363
  _globals['_QUACONFIG_GENERALPORTREFERENCE']._serialized_start=12553
  _globals['_QUACONFIG_GENERALPORTREFERENCE']._serialized_end=12610
  _globals['_QUACONFIG_MULTIPLEOUTPUTS']._serialized_start=12613
  _globals['_QUACONFIG_MULTIPLEOUTPUTS']._serialized_end=12825
  _globals['_QUACONFIG_MULTIPLEOUTPUTS_PORTREFERENCESENTRY']._serialized_start=12724
  _globals['_QUACONFIG_MULTIPLEOUTPUTS_PORTREFERENCESENTRY']._serialized_end=12825
  _globals['_QUACONFIG_ELEMENTDEC']._serialized_start=12828
  _globals['_QUACONFIG_ELEMENTDEC']._serialized_end=15285
  _globals['_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY']._serialized_start=14641
  _globals['_QUACONFIG_ELEMENTDEC_OUTPUTSENTRY']._serialized_end=14735
  _globals['_QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY']._serialized_start=14737
  _globals['_QUACONFIG_ELEMENTDEC_DIGITALINPUTSENTRY']._serialized_end=14846
  _globals['_QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY']._serialized_start=14848
  _globals['_QUACONFIG_ELEMENTDEC_DIGITALOUTPUTSENTRY']._serialized_end=14959
  _globals['_QUACONFIG_ELEMENTDEC_RFINPUTSENTRY']._serialized_start=14961
  _globals['_QUACONFIG_ELEMENTDEC_RFINPUTSENTRY']._serialized_end=15060
  _globals['_QUACONFIG_ELEMENTDEC_RFOUTPUTSENTRY']._serialized_start=15062
  _globals['_QUACONFIG_ELEMENTDEC_RFOUTPUTSENTRY']._serialized_end=15162
  _globals['_QUACONFIG_ELEMENTDEC_OPERATIONSENTRY']._serialized_start=15164
  _globals['_QUACONFIG_ELEMENTDEC_OPERATIONSENTRY']._serialized_end=15213
  _globals['_QUACONFIG_ELEMENTTHREAD']._serialized_start=15287
  _globals['_QUACONFIG_ELEMENTTHREAD']._serialized_end=15322
  _globals['_QUACONFIG_OUTPUTPULSEPARAMETERS']._serialized_start=15325
  _globals['_QUACONFIG_OUTPUTPULSEPARAMETERS']._serialized_end=15663
  _globals['_QUACONFIG_OUTPUTPULSEPARAMETERS_POLARITY']._serialized_start=15622
  _globals['_QUACONFIG_OUTPUTPULSEPARAMETERS_POLARITY']._serialized_end=15663
  _globals['_QUACONFIG_HOLDOFFSET']._serialized_start=15665
  _globals['_QUACONFIG_HOLDOFFSET']._serialized_end=15695
  _globals['_QUACONFIG_STICKY']._serialized_start=15697
  _globals['_QUACONFIG_STICKY']._serialized_end=15756
  _globals['_QUACONFIG_DACPORTREFERENCE']._serialized_start=15758
  _globals['_QUACONFIG_DACPORTREFERENCE']._serialized_end=15825
  _globals['_QUACONFIG_ADCPORTREFERENCE']._serialized_start=15827
  _globals['_QUACONFIG_ADCPORTREFERENCE']._serialized_end=15894
  _globals['_QUACONFIG_DIGITALINPUTPORTREFERENCE']._serialized_start=15896
  _globals['_QUACONFIG_DIGITALINPUTPORTREFERENCE']._serialized_end=16013
  _globals['_QUACONFIG_DIGITALOUTPUTPORTREFERENCE']._serialized_start=16015
  _globals['_QUACONFIG_DIGITALOUTPUTPORTREFERENCE']._serialized_end=16102
  _globals['_QUACONFIG_PORTREFERENCE']._serialized_start=16104
  _globals['_QUACONFIG_PORTREFERENCE']._serialized_end=16168
  _globals['_QUACONFIG_MICROWAVEINPUTPORTREFERENCE']._serialized_start=16170
  _globals['_QUACONFIG_MICROWAVEINPUTPORTREFERENCE']._serialized_end=16282
  _globals['_QUACONFIG_MICROWAVEOUTPUTPORTREFERENCE']._serialized_start=16284
  _globals['_QUACONFIG_MICROWAVEOUTPUTPORTREFERENCE']._serialized_end=16376
  _globals['_QUACONFIG_PULSEDEC']._serialized_start=16379
  _globals['_QUACONFIG_PULSEDEC']._serialized_end=16795
  _globals['_QUACONFIG_PULSEDEC_WAVEFORMSENTRY']._serialized_start=16645
  _globals['_QUACONFIG_PULSEDEC_WAVEFORMSENTRY']._serialized_end=16693
  _globals['_QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY']._serialized_start=16695
  _globals['_QUACONFIG_PULSEDEC_INTEGRATIONWEIGHTSENTRY']._serialized_end=16752
  _globals['_QUACONFIG_PULSEDEC_OPERATION']._serialized_start=16754
  _globals['_QUACONFIG_PULSEDEC_OPERATION']._serialized_end=16795
  _globals['_QUACONFIG_WAVEFORMDEC']._serialized_start=16798
  _globals['_QUACONFIG_WAVEFORMDEC']._serialized_end=17117
  _globals['_QUACONFIG_ARBITRARYWAVEFORMDEC']._serialized_start=17120
  _globals['_QUACONFIG_ARBITRARYWAVEFORMDEC']._serialized_end=17348
  _globals['_QUACONFIG_CONSTANTWAVEFORMDEC']._serialized_start=17350
  _globals['_QUACONFIG_CONSTANTWAVEFORMDEC']._serialized_end=17407
  _globals['_QUACONFIG_WAVEFORMARRAYDEC']._serialized_start=17409
  _globals['_QUACONFIG_WAVEFORMARRAYDEC']._serialized_end=17497
  _globals['_QUACONFIG_WAVEFORMSAMPLES']._serialized_start=17499
  _globals['_QUACONFIG_WAVEFORMSAMPLES']._serialized_end=17533
  _globals['_QUACONFIG_COMPRESSEDWAVEFORMDEC']._serialized_start=17535
  _globals['_QUACONFIG_COMPRESSEDWAVEFORMDEC']._serialized_end=17595
  _globals['_QUACONFIG_DIGITALWAVEFORMDEC']._serialized_start=17597
  _globals['_QUACONFIG_DIGITALWAVEFORMDEC']._serialized_end=17687
  _globals['_QUACONFIG_DIGITALWAVEFORMSAMPLE']._serialized_start=17689
  _globals['_QUACONFIG_DIGITALWAVEFORMSAMPLE']._serialized_end=17743
  _globals['_QUACONFIG_MIXERDEC']._serialized_start=17745
  _globals['_QUACONFIG_MIXERDEC']._serialized_end=17822
  _globals['_QUACONFIG_INTEGRATIONWEIGHTDEC']._serialized_start=17825
  _globals['_QUACONFIG_INTEGRATIONWEIGHTDEC']._serialized_end=17987
  _globals['_QUACONFIG_INTEGRATIONWEIGHTSAMPLE']._serialized_start=17989
  _globals['_QUACONFIG_INTEGRATIONWEIGHTSAMPLE']._serialized_end=18045
  _globals['_QUACONFIG_CORRECTIONENTRY']._serialized_start=18048
  _globals['_QUACONFIG_CORRECTIONENTRY']._serialized_end=18250
  _globals['_QUACONFIG_MATRIX']._serialized_start=18252
  _globals['_QUACONFIG_MATRIX']._serialized_end=18312
  _globals['_QUACONFIG_OCTAVE']._serialized_start=18315
  _globals['_QUACONFIG_OCTAVE']._serialized_end=20620
  _globals['_QUACONFIG_OCTAVE_CONFIG']._serialized_start=18326
  _globals['_QUACONFIG_OCTAVE_CONFIG']._serialized_end=18836
  _globals['_QUACONFIG_OCTAVE_CONFIG_RFOUTPUTSENTRY']._serialized_start=18634
  _globals['_QUACONFIG_OCTAVE_CONFIG_RFOUTPUTSENTRY']._serialized_end=18735
  _globals['_QUACONFIG_OCTAVE_CONFIG_RFINPUTSENTRY']._serialized_start=18737
  _globals['_QUACONFIG_OCTAVE_CONFIG_RFINPUTSENTRY']._serialized_end=18836
  _globals['_QUACONFIG_OCTAVE_LOOPBACK']._serialized_start=18839
  _globals['_QUACONFIG_OCTAVE_LOOPBACK']._serialized_end=19009
  _globals['_QUACONFIG_OCTAVE_SYNTHESIZERPORT']._serialized_start=19011
  _globals['_QUACONFIG_OCTAVE_SYNTHESIZERPORT']._serialized_end=19128
  _globals['_QUACONFIG_OCTAVE_RFOUTPUTCONFIG']._serialized_start=19131
  _globals['_QUACONFIG_OCTAVE_RFOUTPUTCONFIG']._serialized_end=19498
  _globals['_QUACONFIG_OCTAVE_RFINPUTCONFIG']._serialized_start=19501
  _globals['_QUACONFIG_OCTAVE_RFINPUTCONFIG']._serialized_end=19816
  _globals['_QUACONFIG_OCTAVE_SINGLEIFOUTPUTCONFIG']._serialized_start=19818
  _globals['_QUACONFIG_OCTAVE_SINGLEIFOUTPUTCONFIG']._serialized_end=19916
  _globals['_QUACONFIG_OCTAVE_IFOUTPUTSCONFIG']._serialized_start=19919
  _globals['_QUACONFIG_OCTAVE_IFOUTPUTSCONFIG']._serialized_end=20088
  _globals['_QUACONFIG_OCTAVE_SYNTHESIZEROUTPUTNAME']._serialized_start=20090
  _globals['_QUACONFIG_OCTAVE_SYNTHESIZEROUTPUTNAME']._serialized_end=20173
  _globals['_QUACONFIG_OCTAVE_LOSOURCEINPUT']._serialized_start=20175
  _globals['_QUACONFIG_OCTAVE_LOSOURCEINPUT']._serialized_end=20245
  _globals['_QUACONFIG_OCTAVE_LOOPBACKINPUT']._serialized_start=20247
  _globals['_QUACONFIG_OCTAVE_LOOPBACKINPUT']._serialized_end=20346
  _globals['_QUACONFIG_OCTAVE_DOWNCONVERTERRFSOURCE']._serialized_start=20348
  _globals['_QUACONFIG_OCTAVE_DOWNCONVERTERRFSOURCE']._serialized_end=20462
  _globals['_QUACONFIG_OCTAVE_OUTPUTSWITCHSTATE']._serialized_start=20464
  _globals['_QUACONFIG_OCTAVE_OUTPUTSWITCHSTATE']._serialized_end=20564
  _globals['_QUACONFIG_OCTAVE_IFMODE']._serialized_start=20566
  _globals['_QUACONFIG_OCTAVE_IFMODE']._serialized_end=20620
  _globals['_QUACONFIG_VOLTAGELEVEL']._serialized_start=20622
  _globals['_QUACONFIG_VOLTAGELEVEL']._serialized_end=20656
  _globals['_QUACONFIG_OUTPUTSWITCHSTATE']._serialized_start=20464
  _globals['_QUACONFIG_OUTPUTSWITCHSTATE']._serialized_end=20564
# @@protoc_insertion_point(module_scope)



import logging
from typing import List, Type, Tuple, Optional

from google.protobuf.empty_pb2 import Empty
from google.protobuf.wrappers_pb2 import StringValue

from qm.type_hinting import Value
from qm.api.base_api import BaseApi
from qm.api.models.jobs import InsertDirection
from qm.api.models.capabilities import OPX_FEM_IDX
from qm.grpc.qm.pb.frontend_pb2_grpc import FrontendStub
from qm.api.models.quantum_machine import QuantumMachineData
from qm.utils.protobuf_utils import LOG_LEVEL_MAP, proto_repeated_to_list
from qm.api.models.devices import Polarity, MixerInfo, AnalogOutputPortFilter
from qm.api.models.compiler import CompilerOptionArguments, get_request_compiler_options
from qm.grpc.qm.pb import (
    inc_qua_pb2,
    compiler_pb2,
    frontend_pb2,
    inc_qm_api_pb2,
    qm_manager_pb2,
    inc_qua_config_pb2,
    general_messages_pb2,
)
from qm.exceptions import (
    QMRequestError,
    OpenQmException,
    QMConnectionError,
    QMHealthCheckError,
    QMRequestDataError,
    CompilationException,
    FailedToAddJobToQueueException,
    QMFailedToGetQuantumMachineError,
    QmFailedToCloseQuantumMachineError,
    QMFailedToCloseAllQuantumMachinesError,
)

logger = logging.getLogger(__name__)


class FrontendApi(BaseApi[FrontendStub]):
    @property
    def _stub_class(self) -> Type[FrontendStub]:
        return FrontendStub

    def get_version(self) -> str:
        response: StringValue = self._run(self._stub.GetVersion, Empty(), timeout=self._timeout)
        return response.value

    def healthcheck(self, strict: bool) -> None:
        logger.info("Performing health check")
        response = self._run(self._stub.HealthCheck, Empty(), timeout=self._timeout)

        for warning in response.warningMessages:
            logger.warning(f"Health check warning: {warning}")

        for message in response.message:
            logger.debug(message)

        if not response.ok:
            logger.error(f"Health check error: {response.message}")

            for error in response.errorMessages:
                logger.error(f"Health check error: {error}")

            if strict:
                raise QMHealthCheckError("Health check failed")
            return

        logger.info("Health check passed")

    def reset_data_processing(self) -> None:
        self._run(self._stub.ResetDataProcessing, frontend_pb2.ResetDataProcessingRequest(), timeout=self._timeout)

    def open_qm(
        self,
        config: inc_qua_config_pb2.QuaConfig,
        close_other_machines: bool,
        keep_dc_offsets_when_closing: bool = False,
    ) -> str:
        request = qm_manager_pb2.OpenQuantumMachineRequest(
            config=config, keep_dc_offsets_when_closing=keep_dc_offsets_when_closing
        )

        if close_other_machines:
            request.always = True
        else:
            request.never = True

        response: qm_manager_pb2.OpenQuantumMachineResponse = self._run(
            self._stub.OpenQuantumMachine, request, timeout=self._timeout
        )

        if not response.success:
            open_qm_exception = OpenQmException(response.configValidationErrors, response.physicalValidationErrors)

            for formatted_error in (
                open_qm_exception.physical_validation_formatted_errors
                + open_qm_exception.config_validation_formatted_errors
            ):
                logger.error(formatted_error)

            raise open_qm_exception

        for warning in response.openQmWarnings:
            logger.warning(f"Open QM ended with warning {warning.code}: {warning.message}")

        return response.machineID

    def list_open_quantum_machines(self) -> List[str]:
        response = self._run(self._stub.ListOpenQuantumMachines, Empty(), timeout=self._timeout)
        return list(response.machineIDs)

    def get_quantum_machine(self, qm_id: str) -> QuantumMachineData:
        request = qm_manager_pb2.GetQuantumMachineRequest(machineID=qm_id)
        response = self._run(self._stub.GetQuantumMachine, request, timeout=self._timeout)

        if not response.success:
            error_message = "\n".join([error.message for error in response.errors])
            raise QMFailedToGetQuantumMachineError(f"Failed to fetch quantum machine: {error_message}")

        return QuantumMachineData(machine_id=response.machineID, config=response.config)

    def close_quantum_machine(self, machine_id: str) -> bool:
        request = qm_manager_pb2.CloseQuantumMachineRequest(machineID=machine_id)
        response = self._run(self._stub.CloseQuantumMachine, request, timeout=self._timeout)
        if not response.success:
            raise QmFailedToCloseQuantumMachineError("\n".join(err.message for err in response.errors))
        return True

    def get_quantum_machine_config(self, machine_id: str) -> inc_qua_config_pb2.QuaConfig:
        machine_data = self.get_quantum_machine(machine_id)
        config = machine_data.config

        if len(config.v1beta.controlDevices) == 0:
            for controller_name, controller in config.v1beta.controllers.items():
                config.v1beta.controlDevices[controller_name].CopyFrom(
                    inc_qua_config_pb2.QuaConfig.DeviceDec(
                        fems={OPX_FEM_IDX: inc_qua_config_pb2.QuaConfig.FEMTypes(opx=controller)}
                    )
                )
        return machine_data.config

    def close_all_quantum_machines(self) -> None:
        response = self._run(self._stub.CloseAllQuantumMachines, Empty(), timeout=self._timeout)
        if not response.success:
            messages = [error.message for error in response.errors]
            for msg in messages:
                logger.error(msg)

            raise QMFailedToCloseAllQuantumMachinesError(
                "Can not close all quantum machines. See the following errors:\n" + "\n".join(messages),
            )

    def get_controllers(self) -> List[qm_manager_pb2.Controller]:
        response: qm_manager_pb2.GetControllersResponse = self._run(
            self._stub.GetControllers, Empty(), timeout=self._timeout
        )
        return proto_repeated_to_list(response.controllers)

    def clear_all_job_results(self) -> None:
        self._run(self._stub.ClearAllJobResults, Empty(), timeout=self._timeout)

    def send_debug_command(self, controller_name: str, command: str) -> str:
        request = frontend_pb2.PerformHalDebugCommandRequest(controllerName=controller_name, command=command)
        response: frontend_pb2.PerformHalDebugCommandResponse = self._run(
            self._stub.PerformHalDebugCommand, request, timeout=self._timeout
        )

        if not response.success:
            raise QMConnectionError(response.response)
        return response.response

    def add_to_queue(
        self,
        machine_id: str,
        program: inc_qua_pb2.QuaProgram,
        compiler_options: CompilerOptionArguments,
        insert_direction: InsertDirection,
    ) -> str:
        queue_position = frontend_pb2.QueuePosition()
        if insert_direction == InsertDirection.start:
            queue_position.start.CopyFrom(Empty())
        elif insert_direction == InsertDirection.end:
            queue_position.end.CopyFrom(Empty())

        program.compilerOptions.CopyFrom(get_request_compiler_options(compiler_options))

        request = frontend_pb2.AddToQueueRequest(
            quantumMachineId=machine_id,
            highLevelProgram=program,
            queuePosition=queue_position,
        )

        logger.info("Sending program to QOP for compilation")

        response: frontend_pb2.AddToQueueResponse = self._run(self._stub.AddToQueue, request, timeout=None)

        for message in response.messages:
            logger.log(LOG_LEVEL_MAP[message.level], message.message)

        job_id = response.jobId
        if not response.ok:
            logger.error(f"Job {job_id} failed. Failed to execute program.")
            raise FailedToAddJobToQueueException(f"Job {job_id} failed. Failed to execute program.")

        return job_id

    def add_compiled_to_queue(
        self, machine_id: str, program_id: str, execution_overrides: frontend_pb2.ExecutionOverrides
    ) -> str:
        queue_position = frontend_pb2.QueuePosition()
        queue_position.end.CopyFrom(Empty())

        request = frontend_pb2.AddCompiledToQueueRequest(
            quantumMachineId=machine_id,
            programId=program_id,
            queuePosition=queue_position,
            executionOverrides=execution_overrides,
        )

        response: frontend_pb2.AddCompiledToQueueResponse = self._run(
            self._stub.AddCompiledToQueue, request, timeout=self._timeout
        )

        job_id = response.jobId

        for err in response.errors:
            logger.error(err.message)

        if not response.ok:
            logger.error(f"Job {job_id} failed. Failed to execute program.")
            raise FailedToAddJobToQueueException(f"Job {job_id} failed. Failed to execute program.")

        return job_id

    def compile(
        self,
        machine_id: str,
        program: inc_qua_pb2.QuaProgram,
        compiler_options: CompilerOptionArguments,
    ) -> str:
        program.compilerOptions.CopyFrom(get_request_compiler_options(compiler_options))
        request = frontend_pb2.CompileRequest(quantumMachineId=machine_id, highLevelProgram=program)

        response: frontend_pb2.CompileResponse = self._run(self._stub.Compile, request, timeout=None)

        for message in response.messages:
            logger.log(LOG_LEVEL_MAP[message.level], message.message)

        program_id = response.programId
        if not response.ok:
            logger.error(f"Compilation of program {program_id} failed")
            raise CompilationException(f"Compilation of program {program_id} failed")
        return program_id

    def _perform_qm_request(self, request: inc_qm_api_pb2.HighQmApiRequest) -> None:
        response = self._run(self._stub.PerformQmRequest, request, timeout=self._timeout)

        if not response.ok:
            error_message = "\n".join(it.message for it in response.errors)
            logger.error(f"Failed: {error_message}")
            raise QMRequestError(f"Failed: {error_message}")

    def set_correction(self, machine_id: str, mixer: MixerInfo, correction: general_messages_pb2.Matrix) -> None:
        correction_request = inc_qm_api_pb2.HighQmApiRequest.SetCorrection(
            mixer=inc_qm_api_pb2.HighQmApiRequest.SetCorrectionMixerInfo(
                mixer=mixer.mixer,
                frequencyNegative=mixer.frequency_negative,
                intermediateFrequency=mixer.intermediate_frequency,
                intermediateFrequencyDouble=mixer.intermediate_frequency_double,
                loFrequency=mixer.lo_frequency,
                loFrequencyDouble=mixer.lo_frequency_double,
            ),
            # For some reason we have two general_messages_pb2.Matrix messages
            correction=inc_qm_api_pb2.Matrix(
                v00=correction.v00, v01=correction.v01, v10=correction.v10, v11=correction.v11
            ),
            # although they are the same...
        )
        request = inc_qm_api_pb2.HighQmApiRequest(quantumMachineId=machine_id, setCorrection=correction_request)
        self._perform_qm_request(request)

    def set_intermediate_frequency(self, machine_id: str, element: str, value: float) -> None:
        set_frequency_request = inc_qm_api_pb2.HighQmApiRequest.SetFrequency(qe=element, value=value)
        request = inc_qm_api_pb2.HighQmApiRequest(quantumMachineId=machine_id, setFrequency=set_frequency_request)
        self._perform_qm_request(request)

    def set_output_dc_offset(self, machine_id: str, element: str, element_port: str, offset: float) -> None:
        output_dc_offset_request = inc_qm_api_pb2.HighQmApiRequest.SetOutputDcOffset(
            qe=inc_qm_api_pb2.HighQmApiRequest.QePort(qe=element, port=element_port), I=offset, Q=offset
        )
        request = inc_qm_api_pb2.HighQmApiRequest(
            quantumMachineId=machine_id, setOutputDcOffset=output_dc_offset_request
        )
        self._perform_qm_request(request)

    def set_output_filter_taps(
        self,
        machine_id: str,
        element: str,
        element_port: str,
        filter_port: AnalogOutputPortFilter,
    ) -> None:
        output_filter_tap_request = inc_qm_api_pb2.HighQmApiRequest.SetOutputFilterTaps(
            qe=inc_qm_api_pb2.HighQmApiRequest.QePort(qe=element, port=element_port),
            filter=inc_qm_api_pb2.HighQmApiRequest.AnalogOutputPortFilter(
                feedback=filter_port.feedback, feedforward=filter_port.feedforward
            ),
        )
        request = inc_qm_api_pb2.HighQmApiRequest(
            quantumMachineId=machine_id,
            setOutputFilterTaps=output_filter_tap_request,
        )
        self._perform_qm_request(request)

    def set_input_dc_offset(self, machine_id: str, element: str, element_port: str, offset: float) -> None:
        input_dc_offset_request = inc_qm_api_pb2.HighQmApiRequest.SetInputDcOffset(
            qe=inc_qm_api_pb2.HighQmApiRequest.QePort(qe=element, port=element_port), offset=offset
        )
        request = inc_qm_api_pb2.HighQmApiRequest(quantumMachineId=machine_id, setInputDcOffset=input_dc_offset_request)
        self._perform_qm_request(request)

    def set_output_digital_delay(self, machine_id: str, element: str, element_port: str, delay: int) -> None:
        digital_delay_request = inc_qm_api_pb2.HighQmApiRequest.SetDigitalRoute(
            delay=inc_qm_api_pb2.HighQmApiRequest.QePort(qe=element, port=element_port), value=delay
        )
        request = inc_qm_api_pb2.HighQmApiRequest(quantumMachineId=machine_id, setDigitalRoute=digital_delay_request)
        self._perform_qm_request(request)

    def set_output_digital_buffer(self, machine_id: str, element: str, element_port: str, buffer: int) -> None:
        digital_buffer_request = inc_qm_api_pb2.HighQmApiRequest.SetDigitalRoute(
            buffer=inc_qm_api_pb2.HighQmApiRequest.QePort(qe=element, port=element_port), value=buffer
        )
        request = inc_qm_api_pb2.HighQmApiRequest(quantumMachineId=machine_id, setDigitalRoute=digital_buffer_request)
        self._perform_qm_request(request)

    def set_io_values(self, machine_id: str, values: List[Optional[Value]]) -> None:
        type_to_value_mapping = {
            int: "intValue",
            float: "doubleValue",
            bool: "booleanValue",
        }

        set_data = []
        for index, value in enumerate(values):
            if value is not None:
                set_data_request = inc_qm_api_pb2.HighQmApiRequest.IOValueSetData(io_number=index + 1)
                setattr(set_data_request, type_to_value_mapping[type(value)], value)
                set_data.append(set_data_request)

        set_io_values = inc_qm_api_pb2.HighQmApiRequest.SetIOValues(all=True, ioValueSetData=set_data)
        request = inc_qm_api_pb2.HighQmApiRequest(quantumMachineId=machine_id, setIOValues=set_io_values)
        self._perform_qm_request(request)

    def set_digital_input_threshold(
        self, machine_id: str, controller_name: str, fem_number: int, port_number: int, threshold: float
    ) -> None:
        digital_input_threshold_request = inc_qm_api_pb2.HighQmApiRequest.SetDigitalInputThreshold(
            digitalPort=inc_qm_api_pb2.DigitalInputPort(
                controllerName=controller_name, fem_Number=fem_number, portNumber=port_number
            ),
            threshold=threshold,
        )
        request = inc_qm_api_pb2.HighQmApiRequest(
            quantumMachineId=machine_id,
            setDigitalInputThreshold=digital_input_threshold_request,
        )
        self._perform_qm_request(request)

    def set_digital_input_dead_time(
        self, machine_id: str, controller_name: str, fem_number: int, port_number: int, dead_time: int
    ) -> None:
        digital_input_dead_time_request = inc_qm_api_pb2.HighQmApiRequest.SetDigitalInputDeadtime(
            digitalPort=inc_qm_api_pb2.DigitalInputPort(
                controllerName=controller_name, fem_Number=fem_number, portNumber=port_number
            ),
            deadtime=dead_time,
        )
        request = inc_qm_api_pb2.HighQmApiRequest(
            quantumMachineId=machine_id,
            setDigitalInputDeadtime=digital_input_dead_time_request,
        )
        self._perform_qm_request(request)

    def set_digital_input_polarity(
        self,
        machine_id: str,
        controller_name: str,
        fem_number: int,
        port_number: int,
        polarity: Polarity,
    ) -> None:
        digital_input_polarity_request = inc_qm_api_pb2.HighQmApiRequest.SetDigitalInputPolarity(
            digitalPort=inc_qm_api_pb2.DigitalInputPort(
                controllerName=controller_name, fem_Number=fem_number, portNumber=port_number
            ),
            polarity=polarity.value,
        )
        request = inc_qm_api_pb2.HighQmApiRequest(
            quantumMachineId=machine_id,
            setDigitalInputPolarity=digital_input_polarity_request,
        )
        self._perform_qm_request(request)

    def get_io_values(self, machine_id: str) -> Tuple[compiler_pb2.QuaValues, ...]:
        request = frontend_pb2.QmDataRequest(
            io_value_Request=[
                frontend_pb2.IOValueRequest(io_number=1, quantumMachineId=machine_id),
                frontend_pb2.IOValueRequest(io_number=2, quantumMachineId=machine_id),
            ]
        )
        response = self._run(self._stub.RequestData, request, timeout=self._timeout)

        if not response.success:
            raise QMRequestDataError("\n".join(err.message for err in response.errors))

        return tuple(resp.values for resp in response.io_value_response)
